==> owncloud-5.0.9.tgz: owncloud/lib/l10n/bg_BG.php <==
<?php $TRANSLATIONS = array(
"Help" => "Помощ",
"Personal" => "Лични",
"Settings" => "Настройки",
"Users" => "Потребители",
"Apps" => "Приложения",
"Admin" => "Админ",
"ZIP download is turned off." => "Изтеглянето като ZIP е изключено.",
"Files need to be downloaded one by one." => "Файловете трябва да се изтеглят един по един.",
"Back to Files" => "Назад към файловете",
"Selected files too large to generate zip file." => "Избраните файлове са прекалено големи за генерирането на ZIP архив.",
"couldn't be determined" => "не може да се определи",
"Application is not enabled" => "Приложението не е включено.",
"Authentication error" => "Възникна проблем с идентификацията",
"Token expired. Please reload page." => "Ключът е изтекъл, моля презаредете страницата",
"Files" => "Файлове",
"Text" => "Текст",
"Images" => "Снимки",
"Set an admin username." => "Въведете потребителско име за администратор.",
"Set an admin password." => "Въведете парола за администратор.",
"Specify a data folder." => "Укажете папка за данни",
"%s enter the database username." => "%s въведете потребителско име за базата с данни.",
"%s enter the database name." => "%s въведете име на базата с данни.",
"%s you may not use dots in the database name" => "%s, не можете да ползвате точки в името на базата от данни",
"PostgreSQL username and/or password not valid" => "Невалидно PostgreSQL потребителско име и/или парола",
"You need to enter either an existing account or the administrator." => "Необходимо е да влезете в всъществуващ акаунт или като администратора",
"Oracle username and/or password not valid" => "Невалидно Oracle потребителско име и/или парола",
"MySQL username and/or password not valid" => "Невалидно MySQL потребителско име и/или парола",
"DB Error: \"%s\"" => "Грешка в базата от данни: \"%s\"",
"MySQL user '%s'@'localhost' exists already." => "MySQL потребителят '%s'@'localhost' вече съществува",
"Drop this user from MySQL" => "Изтриване на потребителя от MySQL",
"MySQL user '%s'@'%%' already exists" => "MySQL потребителят  '%s'@'%%' вече съществува.",
"Drop this user from MySQL." => "Изтриване на потребителя от MySQL.",
"MS SQL username and/or password not valid: %s" => "Невалидно MS SQL потребителско име и/или парола: %s",
"Please double check the <a href='%s'>installation guides</a>." => "Моля направете повторна справка с <a href='%s'>ръководството за инсталиране</a>.",
"seconds ago" => "преди секунди",
"1 minute ago" => "преди 1 минута",
"%d minutes ago" => "преди %d минути",
"1 hour ago" => "преди 1 час",
"%d hours ago" => "преди %d часа",
"today" => "днес",
"yesterday" => "вчера",
"%d days ago" => "преди %d дни",
"last month" => "последният месец",
"%d months ago" => "преди %d месеца",
"last year" => "последната година",
"years ago" => "последните години",
"%s is available. Get <a href=\"%s\">more information</a>" => "%s е налична. Получете <a href=\"%s\">повече информация</a>",
"up to date" => "е актуална",
"updates check is disabled" => "проверката за обновления е изключена",
"Could not find category \"%s\"" => "Невъзможно откриване на категорията \"%s\""
);

==> owncloud-7.0.4.tgz: owncloud/lib/l10n/bg_BG.php <==
<?php
$TRANSLATIONS = array(
"Help" => "Помощ",
"Personal" => "Лични",
"Settings" => "Настройки",
"Users" => "Потребители",
"Admin" => "Админ",
"web services under your control" => "уеб услуги под Ваш контрол",
"Application is not enabled" => "Приложението не е включено.",
"Authentication error" => "Възникна проблем с идентификацията",
"Token expired. Please reload page." => "Ключът е изтекъл, моля презаредете страницата",
"%s enter the database username." => "%s въведете потребителско име за базата с данни.",
"%s enter the database name." => "%s въведете име на базата с данни.",
"%s you may not use dots in the database name" => "%s, не можете да ползвате точки в името на базата от данни",
"MS SQL username and/or password not valid: %s" => "Невалидно MS SQL потребителско име и/или парола: %s",
"You need to enter either an existing account or the administrator." => "Необходимо е да влезете в всъществуващ акаунт или като администратора",
"DB Error: \"%s\"" => "Грешка в базата от данни: \"%s\"",
"Offending command was: \"%s\"" => "Проблемната команда беше: \"%s\"",
"Oracle connection could not be established" => "Oracle връзка не можа да се осъществи",
"Oracle username and/or password not valid" => "Невалидно Oracle потребителско име и/или парола",
"Offending command was: \"%s\", name: %s, password: %s" => "Проблемната команда беше: \"%s\", име: %s, парола: %s",
"PostgreSQL username and/or password not valid" => "Невалидно PostgreSQL потребителско име и/или парола",
"Set an admin username." => "Въведете потребителско име за администратор.",
"Set an admin password." => "Въведете парола за администратор.",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Вашият web сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът изглежда не работи.",
"Please double check the <a href='%s'>installation guides</a>." => "Моля направете повторна справка с <a href='%s'>ръководството за инсталиране</a>.",
"Could not find category \"%s\"" => "Невъзможно откриване на категорията \"%s\"",
"seconds ago" => "преди секунди",
"_%n minute ago_::_%n minutes ago_" => array("",""),
"_%n hour ago_::_%n hours ago_" => array("",""),
"today" => "днес",
"yesterday" => "вчера",
"_%n day go_::_%n days ago_" => array("",""),
"last month" => "последният месец",
"_%n month ago_::_%n months ago_" => array("",""),
"last year" => "последната година",
"years ago" => "последните години"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
